@@ -1,36 +1,23 @@
 mod common;
 use common::SimpleVal;
-use logos::Logos;
-use skiff::type_inferencer::type_inference::{self, InferenceError};
-use skiff::type_inferencer::util::add_any_to_declarations;
-use skiff::{error_handling, interpreter::interpret, lexer::lex, parser::parse};
+use skiff::runtime::{evaluate, CliArgs, SkiffError};
 use std::collections::HashMap;
+use std::fmt::Write;
 use std::fs::{self, ReadDir};
-use std::{borrow::Borrow, ops::Range};
 
 static VERBOSE: bool = true;
 
-#[derive(PartialEq, Debug)]
-struct TestError {
-    message: String,
-    span: Option<Range<usize>>,
-    source: String,
-    filename: std::path::PathBuf,
-}
-impl TestError {
-    fn print(&self) {
-        match self.span.clone() {
-            Some(span) => error_handling::pretty_print_error(
-                self.message.borrow(),
-                span,
-                self.source.borrow(),
-                self.filename.clone(),
-            ),
-            None => println!("{}", self.message),
-        }
+struct ConsolePrinter;
+impl Write for ConsolePrinter {
+    fn write_str(&mut self, s: &str) -> core::fmt::Result {
+        println!("{}", s);
+        Ok(())
     }
 }
 
+#[derive(PartialEq, Debug, Clone, Hash)]
+struct TestError(SkiffError);
+
 #[test]
 pub fn diff_test() {
     let success_directory = "./tests/files/success";
@@ -98,9 +85,7 @@ fn run_paths(paths: ReadDir, expected_outputs: Option<HashMap<&str, Vec<SimpleVa
                     Some(_) => {
                         // If running the file errors, log the name and fail.
                         println!("Name: {:?}", path);
-                        if VERBOSE {
-                            e.print();
-                        }
+                        println!("Error: {:?}", e);
                         assert!(false);
                     }
                     None => assert!(true),
@@ -113,70 +98,10 @@ fn run_paths(paths: ReadDir, expected_outputs: Option<HashMap<&str, Vec<SimpleVa
 fn run_file<'a>(path: std::path::PathBuf) -> Result<Vec<SimpleVal>, TestError> {
     let raw = fs::read_to_string(path.clone()).expect("Something went wrong reading the file");
 
-    let lexer = lex::Token::lexer(&raw);
-
-    let mut token_vec: Vec<_> = lexer.spanned().collect();
-
-    // Check for error tokens
-    for (token, span) in &token_vec {
-        if token == &lex::Token::Error {
-            return Err(TestError {
-                message: "Invalid token".to_string(),
-                span: Some(span.clone()),
-                source: raw,
-                filename: path,
-            });
-        }
-    }
-
-    token_vec.reverse();
-
-    // Parse and check for errors
-    let parsed = match parse::parse_program(&mut token_vec) {
-        Ok(v) => v,
-        Err(e) => {
-            return Err(TestError {
-                message: e.0,
-                span: None,
-                source: raw,
-                filename: path,
-            })
-        }
-    };
-
-    let parsed_with_anys = add_any_to_declarations(parsed);
-
-    match type_inference::infer_types(&parsed_with_anys) {
-        Err(InferenceError::ConstructorMismatch(t1, t2)) => {
-            return Err(TestError {
-                message: format!("Type mismatch: {} is not {}", t1, t2),
-                span: None,
-                source: raw,
-                filename: path,
-            })
-        }
-        Err(e) => {
-            return Err(TestError {
-                message: format!("Inference error {:?}", e),
-                span: None,
-                source: raw,
-                filename: path,
-            })
-        }
-        _ => (),
-    };
-
-    // Interpret and check for errors
-    let output = match interpret::interpret(&parsed_with_anys) {
-        Ok(output) => output,
-        Err(interpret::InterpError(msg, span, _, _)) => {
-            return Err(TestError {
-                message: msg,
-                span: Some(span),
-                source: raw,
-                filename: path,
-            });
-        }
+    let output = match evaluate(CliArgs::new(path), raw, &mut ConsolePrinter) {
+        Ok(Some(o)) => o,
+        Ok(None) => panic!("Test run aborted early"),
+        Err(e) => return Err(TestError(e)),
     };
 
     // Gather output
